/*
	Thanks to the parent_type variable, the /b17 object can opperate all on it's own,
	without us having to understand how exactly it works. We do need to understand how
	to use it, though. All modules can be thought of in terms of input and output.
	For the /b17 object, input and output both run through the client.

	The game's input is provided via the launch proc, which accepts five arguments
	(the last two are optional):

		-- The first argument is a client object; /b17 will	attach a new mob to this
			client, so if you want to keep your old mob, you'll need to store it
			somewhere before launching the game.

		-- The second argument is an object which /b17 will send a message to once
			the game is over. This can be any type of object.

		-- The third argument is the message /b17 will send once the game is over. This
			must be the name of a proc (or verb) which the second argument has.

		-- The forth argument (optional) is the width you would like the game to be.
			This defaults to a width of 15 (turfs).

		-- The fifth argument (optional) is the height you would like the game to be.
			This defaults to a height of 15 (turfs).

	The game's output is that is calls a proc. That proc is whatever we provided as the
	third argument to launch().

	Now, all we need to do is provide the user with a way to start the entire process.
	*/

client/verb/Start()
	set name = ".start"
	var/b17/game = new()
	game.launch(
		src,    // The client we send the game will be the client using the verb.
		src,    // The object which the game will inform when it's done will be this client.
		"reset" // The proc which the game will call will be the "reset" proc, defined below.
		)

client/proc/reset(){
	/*
		This proc will be run when the game ends. When a game of /b17 is over, it cleans
		itself up, and deletes all objects it used, including the player mob. It's a good
		idea to give the client a new mob before that happens, so your player doesn't get
		disconnected.
		*/
	mob = new(locate(1,1,1))
	eye = mob
	}





/*
	The rest of the file provides a world for B17 to run in, so that it can be tested
	without including it in another project. Most of what is defined below are procs the
	skin system will interact with.
	*/
#include "arcade.dmf"
world{
	maxx = 15
	maxy = 15
	maxz = 1
	name = "B17: Solo Fortress"
	}
client/New(){
	.=..()
	var/icon/title_graphic = icon('title.png')
	for(var/state in icon_states(title_graphic)){
		if(!findtext(state,",")){ continue}
		var/x_pos = text2num(copytext(state,1,findtext(state,",")))+1
		var/y_pos = text2num(copytext(state,findtext(state,",")+1))+1
		var/turf/T = locate(x_pos, y_pos, 1)
		T.icon = title_graphic
		T.icon_state = state
		}
	}
client/perspective = EDGE_PERSPECTIVE
client/verb/_reboot(){
	set name = ".force_reboot"
	world.Reboot()
	}
client/verb/_quit(){
	set name = ".quit"
	world.Del()
	}
client/Center(){
	if(hascall(mob,"drop bomb")){
		mob:drop_bomb()
		}
	}
client/verb/Resize(mode as num){
	set name = ".resize"
	switch(mode){
		if(1){ winset(src,"main_window","is-maximized=false;size=240x240")}
		if(2){ winset(src,"main_window","is-maximized=false;size=480x480")}
		if(0){ winset(src,"main_window","is-maximized=true"              )}
		}
	}